/*
 *  Copyright (C) 2003, 2004 Laurent Sansonetti <lrz@gnome.org>
 *
 *  This file is part of Ruby/Libburn.
 *
 *  Ruby/Libburn is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  Ruby/Libburn is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Ruby/Libburn; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "rbburn.h"

/* Class: Burn::Message
 * Messages from the library.
 */
static VALUE cBurnMessage;

VALUE
rbburn_message_make (struct burn_message *c_struct)
{
	return c_struct != NULL
		? Data_Wrap_Struct (cBurnMessage,
				    NULL,
				    burn_message_free,
				    c_struct)
		: Qnil;
}

static struct burn_message *
rbburn_message_get (VALUE obj)
{
	struct burn_message *c_struct;
	
	Data_Get_Struct(obj, struct burn_message, c_struct);
	assert (c_struct != NULL);
	return c_struct;
}

/*
 * Method: mtype
 *
 * Gets the type of the message.
 *
 * Returns: a message type (either Burn::Message::TYPE_INFO,
 * Burn::Message::TYPE_WARNING, Burn::Message::TYPE_ERROR).
 */
static VALUE
rbburn_message_get_type (VALUE self)
{
	struct burn_message *msg = rbburn_message_get (self);
	return INT2FIX (msg->type);
}

/*
 * Method: message
 *
 * Gets the actual message.
 * 
 * Returns: always nil (not yet implemented).
 */
static VALUE
rbburn_message_get_message (VALUE self)
{
	/* not yet implemented in the native library 
	struct burn_message *msg = rbburn_message_get (self);
	switch (msg->type) {
	case BURN_MESSAGE_INFO:
	case BURN_MESSAGE_WARNING:
	case BURN_MESSAGE_ERROR:
	} */
	return Qnil;
}

void
rbburn_message_init (VALUE mBurn)
{
	VALUE c = rb_define_class_under (mBurn, "Message", rb_cObject);
	rb_undef_method (CLASS_OF (c), "new");
	rb_define_method (c, "mtype", rbburn_message_get_type, 0);
	rb_define_method (c, "message", rbburn_message_get_message, 0);
	rb_define_alias (c, "to_s", "message");

	/* Constant: TYPE_INFO
	 * Diagnostic/Process information. For the curious user.
	 */
	rb_define_const (c, "TYPE_INFO", INT2NUM (BURN_MESSAGE_INFO));

	/* Constant: TYPE_WARNING
	 * A warning regarding a possible problem. The user should probably
	 * be notified, but its not fatal.
	 */
	rb_define_const (c, "TYPE_WARNING", INT2NUM (BURN_MESSAGE_WARNING));

	/* Constant: TYPE_ERROR
	 * An error message. This usually means the current process will be
	 * aborted, and the user should definately see these. 
	 */
	rb_define_const (c, "TYPE_ERROR", INT2NUM (BURN_MESSAGE_ERROR));
	cBurnMessage = c;
}
