/*
 *  Copyright (C) 2003, 2004 Laurent Sansonetti <lrz@gnome.org>
 *
 *  This file is part of Ruby/Libburn.
 *
 *  Ruby/Libburn is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  Ruby/Libburn is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Ruby/Libburn; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "rbburn.h"

/* Class: Burn::Progress
 * Operation progress report.  All values are 0 based indices.
 */
static VALUE cBurnProgress;

VALUE
rbburn_progress_make (struct burn_progress *c_struct)
{
        return c_struct != NULL
		? Data_Wrap_Struct (cBurnProgress,
				    NULL,
				    free,
				    c_struct)
		: Qnil;
}

static struct burn_progress *
rbburn_progress_get (VALUE obj)
{
	struct burn_progress *c_struct;

	Data_Get_Struct(obj, struct burn_progress, c_struct);
	assert (c_struct != NULL);
	return c_struct;
}

/* Method: sessions
 * Returns: the total number of sessions.
 */
static VALUE
rbburn_progress_get_sessions (VALUE self)
{
	struct burn_progress *pg = rbburn_progress_get (self);
	return INT2FIX (pg->sessions);
}

/* Method: session
 * Returns: the current session.
 */
static VALUE
rbburn_progress_get_session (VALUE self)
{
	struct burn_progress *pg = rbburn_progress_get (self);
	return INT2FIX (pg->session);
}

/* Method: tracks
 * Returns: the total number of tracks.
 */
static VALUE
rbburn_progress_get_tracks (VALUE self)
{
	struct burn_progress *pg = rbburn_progress_get (self);
	return INT2FIX (pg->tracks);
}

/* Method: track
 * Returns: the current track.
 */
static VALUE
rbburn_progress_get_track (VALUE self)
{
	struct burn_progress *pg = rbburn_progress_get (self);
	return INT2FIX (pg->track);
}

/* Method: indices
 * Returns: the total number of indices.
 */
static VALUE
rbburn_progress_get_indices (VALUE self)
{
	struct burn_progress *pg = rbburn_progress_get (self);
	return INT2FIX (pg->indices);
}

/* Method: index
 * Returns: the current index.
 */
static VALUE
rbburn_progress_get_index (VALUE self)
{
	struct burn_progress *pg = rbburn_progress_get (self);
	return INT2FIX (pg->index);
}

/* Method: start_sector
 * Returns: the starting logical block address. 
 */
static VALUE
rbburn_progress_get_start_sector (VALUE self)
{
	struct burn_progress *pg = rbburn_progress_get (self);
	return INT2FIX (pg->start_sector);
}

/* Method: sectors
 * Returns: the total number of sectors.
 */
static VALUE
rbburn_progress_get_sectors (VALUE self)
{
	struct burn_progress *pg = rbburn_progress_get (self);
	return INT2FIX (pg->sectors);
}

/* Method: current_sector
 * Returns: the current sector being processed. 
 */
static VALUE
rbburn_progress_get_current_sector (VALUE self)
{
	struct burn_progress *pg = rbburn_progress_get (self);
	return INT2FIX (pg->current_sector);
}
void
rbburn_progress_init (VALUE mBurn)
{
	VALUE c = rb_define_class_under (mBurn, "Progress", rb_cObject);
	rb_undef_method (CLASS_OF (c), "new");
	rb_define_method (c, "sessions", rbburn_progress_get_sessions, 0);
	rb_define_method (c, "session", rbburn_progress_get_session, 0);
	rb_define_method (c, "tracks", rbburn_progress_get_tracks, 0);
	rb_define_method (c, "track", rbburn_progress_get_track, 0);
	rb_define_method (c, "indices", rbburn_progress_get_indices, 0);
	rb_define_method (c, "index", rbburn_progress_get_index, 0);
	rb_define_method (
		c, "start_sector", rbburn_progress_get_start_sector, 0);
	rb_define_method (c, "sectors", rbburn_progress_get_sectors, 0);
	rb_define_method (
		c, "current_sector", rbburn_progress_get_current_sector, 0);
	rb_define_alias (c, "sector", "current_sector");
	cBurnProgress = c;
}
