/*
 *  Copyright (C) 2003, 2004 Laurent Sansonetti <lrz@gnome.org>
 *
 *  This file is part of Ruby/Libburn.
 *
 *  Ruby/Libburn is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  Ruby/Libburn is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Ruby/Libburn; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "rbburn.h"

/* Class: Burn::Source
 * Data source for tracks.
 */
static VALUE cBurnSource;

VALUE
rbburn_source_make (struct burn_source *c_struct)
{
	return c_struct != NULL
		? Data_Wrap_Struct (cBurnSource,
				    NULL,
				    burn_source_free,
				    c_struct)
		: Qnil;
}

struct burn_source *
rbburn_source_get (VALUE obj)
{
	struct burn_source *c_struct;

	Data_Get_Struct(obj, struct burn_source, c_struct);
	assert (c_struct != NULL);
	return c_struct;
}

/*
 * Class method: new(path, subpath)
 * path: path of the data source.
 * subpath: sub path of the data source.
 * 
 * Creates a data source for an image file (and maybe subcode file).
 *
 * Returns: a newly allocated Burn::Source object.
 */
static VALUE 
rbburn_source_new (VALUE self, VALUE path, VALUE subpath)
{
	return rbburn_source_make (burn_file_source_new (RVAL2CSTR (path),
							 RVAL2CSTR (subpath)));
}

void
rbburn_source_init (VALUE mBurn)
{
	VALUE c = rb_define_class_under (mBurn, "Source", rb_cObject);
	rb_define_singleton_method (c, "new", rbburn_source_new, 2);

	/* Constant: STATUS_OK
	 * The source is ok.
	 */
	rb_define_const (c, "STATUS_OK", INT2FIX (BURN_SOURCE_OK));

	/* Constant: STATUS_EOF
	 * The source is at the end of the file.
	 */
	rb_define_const (c, "STATUS_EOF", INT2FIX (BURN_SOURCE_EOF));

	/* Constant: STATUS_FAILED
	 * The source is unusable.
	 */
	rb_define_const (c, "STATUS_FAILED", INT2FIX (BURN_SOURCE_FAILED));
	cBurnSource = c;
}
